<?php

require_once(__DIR__ . DS . 'lib' . DS . 'Core.php');

use Blesta\Core\Util\Common\Traits\Container;

/**
 * Netim Account main controller
 *
 * @package Netim
 */
class AdminMain extends NetimOperationsPendingController
{
    /**
     * Pre-action
     */
    public function preAction()
    {
        parent::preAction();
        
        $this->uses(['ModuleManager']);
        
        Language::loadLang('admin_main', null, PLUGINDIR . 'netim_operations_pending' . DS . 'language' . DS); 
        
        Loader::loadComponents($this, ['Input', 'Record']);
    }

    /**
     * Renders the system overview widget
     */
    public function index()
    {
        global $_SERVER;
        $error = "";
        
        // Only available via AJAX
        if (!$this->isAjax()) {
            $this->redirect($this->base_uri);
        }

        //Get module rows
        $netim_module=$this->ModuleManager->getByClass("netim")[0];
        $module = $this->ModuleManager->get($netim_module->id, true, false );
        $operations["ALL"] = [];

        foreach($module->rows as $row)
        {
            $operations[$row->meta->user] = [];

            $api = $this->getApi($row->meta->user, $row->meta->key, $row->meta->sandbox);

            try
            {
                $opes[$row->meta->user] = $api->queryOpePending();
                foreach($opes[$row->meta->user] as $ope){
                    $id = $ope->id_ope;
                    $domainName = idn_to_utf8($ope->data_ope, IDNA_NONTRANSITIONAL_TO_ASCII); 
                    $operation = $ope->code_ope;
                    $date = date("M d,y H:i:s",strtotime($ope->date_ope));
                    $IDdomains = Netim\Core\GetDomainID($this->Record,$domainName);
                    $IDclient = Netim\Core\GetClientID($this->Record,$IDdomains);
                    $operations[$row->meta->user][$id] = [
                        "id" => $id,
                        "domainName" => $domainName,
                        "operation" => $operation,
                        "date" => $date,
                        "idDomain" => $IDdomains,
                        "idClient" => $IDclient
                    ];
                    $operations["ALL"][$id] = [
                        "id" => $id,
                        "compte" => $row->meta->user,
                        "domainName" => $domainName,
                        "operation" => $operation,
                        "date" => $date,
                        "idDomain" => $IDdomains,
                        "idClient" => $IDclient
                    ];
                }
                
            }
            catch(SoapFault $fault)
            {
                $error = $fault->getMessage();
            }
            ksort($operations[$row->meta->user]);
        }
        ksort($operations['ALL']);

        $this->set('module', $module);
        $this->set('operations', $operations);
        $this->set('error', $error);
        return $this->renderAjaxWidgetIfAsync(isset($this->get[0]) ? false : null);
    }

    /**
     * Initializes the NETIM and returns an instance of that object
     *
     * @param string $user The user to connect as
     * @param string $key The key to use when connecting
     * @param bool $sandbox Whether or not to process in sandbox mode (for testing)
     * @return APISoap The ClientAPI instance
     */
    private function getApi($user, $key, $sandbox = false)
    {
        global $_SERVER;
        Loader::load( $_SERVER['DOCUMENT_ROOT'] . DS . 'components' . DS . 'modules' .DS . 'netim' . DS . 'api' . DS . 'APISoap.php');

        if(!is_bool($sandbox))
            $sandbox=($sandbox=="true");

        $api = new Netim\APISoap($user, $key, $sandbox);
        
        //$api->setKeepAlive(true);

        //Don't update SetVersion(), it used by NETIM to track and follow module usage
        $api->SetVersion("BLESTA=".BLESTA_VERSION.";PLUGIN=1");
                
        return $api;
    }
}
